@@ -1106,12 +1106,9 @@ parse_http_response (char                *buf,
                                          *headers,
                                          NULL,
                                          &status_code,
-                                         NULL)) {
-                if (status_code == 200)
-                        *type = _GSSDP_DISCOVERY_RESPONSE;
-                else
-                        g_warning ("Unhandled status code '%d'", status_code);
-
+                                         NULL) &&
+            status_code == 200) {
+                *type = _GSSDP_DISCOVERY_RESPONSE;
                 return TRUE;
         } else {
                 soup_message_headers_free (*headers);
@@ -1225,8 +1222,8 @@ socket_source_cb (GSSDPSocketSource *socket_source, GSSDPClient *client)
         /* Find length */
         end = strstr (buf, "\r\n\r\n");
         if (!end) {
-                g_warning ("Received packet lacks \"\\r\\n\\r\\n\" sequence. "
-                           "Packed dropped.");
+                g_debug ("Received packet lacks \"\\r\\n\\r\\n\" sequence. "
+                         "Packed dropped.");
 
                 goto out;
         }
@@ -1245,7 +1242,7 @@ socket_source_cb (GSSDPSocketSource *socket_source, GSSDPClient *client)
                                           len,
                                           &headers,
                                           &type)) {
-                        g_warning ("Unhandled message '%s'", buf);
+                        g_debug ("Unhandled packet '%s'", buf);
                 }
         }
         
